/v1/version — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/version

Contents

- /v1/version
  - GET /v1/version
    - Response status codes
    - Output
  - POST /v1/version
    - Response status codes
    - Input
    - Output

## GET /v1/version

Retrieve the server version number

### Response status codes

- 200: OK

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
version | ✔ | string | Version number human readable

## POST /v1/version

Check if version is the same as the server

### Response status codes

- 200: Same version
- 409: Invalid version

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
version | ✔ | string | Version number human readable

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
version | ✔ | string | Version number human readable

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »